Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(424)

Unified Diff: third_party/WebKit/Source/core/input/PointerEventManager.h

Issue 2914673002: Refactor TouchEventManager::TouchInfo class (Closed)
Patch Set: Rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/input/PointerEventManager.h
diff --git a/third_party/WebKit/Source/core/input/PointerEventManager.h b/third_party/WebKit/Source/core/input/PointerEventManager.h
index d8b97b42b300b42052b490b159457fa4b7befd2f..f1bf20968ab89005dbdc38b892f08ce025fab9ed 100644
--- a/third_party/WebKit/Source/core/input/PointerEventManager.h
+++ b/third_party/WebKit/Source/core/input/PointerEventManager.h
@@ -141,15 +141,19 @@ class CORE_EXPORT PointerEventManager
// blockTouchPointers().
void UnblockTouchPointers();
- // Generate the TouchInfos for a WebTouchEvent, hit-testing as necessary.
- void ComputeTouchTargets(const WebTouchEvent&,
- HeapVector<TouchEventManager::TouchInfo>&);
+ // Returns PointerEventTarget for a WebTouchPoint, hit-testing as necessary.
+ EventHandlingUtil::PointerEventTarget ComputePointerEventTarget(
+ const WebTouchPoint&);
// Sends touch pointer events and sets consumed bits in TouchInfo array
// based on the return value of pointer event handlers.
- void DispatchTouchPointerEvents(const WebTouchEvent&,
- const Vector<WebTouchEvent>& coalesced_events,
- HeapVector<TouchEventManager::TouchInfo>&);
+ void DispatchTouchPointerEvent(
+ const WebTouchPoint&,
+ const EventHandlingUtil::PointerEventTarget&,
+ const Vector<std::pair<WebTouchPoint, TimeTicks>>& coalesced_events,
+ WebInputEvent::Modifiers,
+ double timestamp,
+ uint32_t unique_touch_event_id);
// Returns whether the event is consumed or not.
WebInputEventResult SendTouchPointerEvent(EventTarget*, PointerEvent*);
« no previous file with comments | « third_party/WebKit/Source/core/input/EventHandlingUtil.h ('k') | third_party/WebKit/Source/core/input/PointerEventManager.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698